@@ -2,6 +2,9 @@ set.seed(1234)
 n <- 80000
 nreps <- 10
 
+# cont Y just for testing that function runs
+df_sel$Y_cont <- plogis(df_sel$Y) + rnorm(nrow(df_sel), mean = 0, sd = 0.1)
+
 # 0 confounders
 
 nobias_model <- glm(Y ~ X,
@@ -15,7 +18,7 @@ s_model <- glm(S ~ X + Y,
 single_run <- adjust_sel(
   df_sel,
   exposure = "X",
-  outcome = "Y",
+  outcome = "Y_cont",
   s_model_coefs = c(
     s_model$coef[1],
     s_model$coef[2],
@@ -65,7 +68,7 @@ s_model <- glm(S ~ X + Y,
 single_run <- adjust_sel(
   df_sel,
   exposure = "X",
-  outcome = "Y",
+  outcome = "Y_cont",
   confounders = "C1",
   s_model_coefs = c(
     s_model$coef[1],
@@ -117,7 +120,7 @@ s_model <- glm(S ~ X + Y,
 single_run <- adjust_sel(
   df_sel,
   exposure = "X",
-  outcome = "Y",
+  outcome = "Y_cont",
   confounders = c("C1", "C2"),
   s_model_coefs = c(
     s_model$coef[1],
@@ -169,7 +172,7 @@ s_model <- glm(S ~ X + Y,
 single_run <- adjust_sel(
   df_sel,
   exposure = "X",
-  outcome = "Y",
+  outcome = "Y_cont",
   confounders = c("C1", "C2", "C3"),
   s_model_coefs = c(
     s_model$coef[1],
